

class SystemNotSupport(Exception):
    msg = "Current system {name} is not supported."

    def __init__(self, **kwargs):
        self.kwargs = kwargs
        self.message = self.msg.format(**kwargs)

    def __str__(self):
        return self.message



import os
import platform

from ctypes import cdll, c_char_p

from .exceptions import SystemNotSupport


def parse(tf_dir: str) -> str:

    system = platform.system()
    if system not in ("Darwin", "Linux", "Windows"):
        raise SystemNotSupport(name=system)
    lib = cdll.LoadLibrary(os.path.join(os.path.dirname(os.path.abspath(__file__)), f"parse_{system.lower()}.so"))
    parser_tf = lib.ParserTf

    parser_tf.argtype = c_char_p
    parser_tf.restype = c_char_p

    output = parser_tf(tf_dir.encode())

    return output.decode()



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()
setuptools.setup(
    name="parsetf",
    version="1.1",
    author="web",
    author_email="willweb@126.com",
    description="parse terraform template",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(),
    package_data={
        "parsetf": [
            "*.py",
            "*.so",
        ]
    },
    classifiers=[
        "Intended Audience :: Developers",
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Topic :: Software Development",
    ],
    install_requires=[],
    python_requires='>=3.6',
)
